@@ -95,9 +95,9 @@ modules = [
     "naver",
     "naverwebtoon",
     "newgrounds",
-    "ngomik",
     "nhentai",
     "nijie",
+    "nitter",
     "nozomi",
     "nsfwalbum",
     "paheal",
@@ -141,6 +141,7 @@ modules = [
     "twibooru",
     "twitter",
     "unsplash",
+    "uploadir",
     "vanillarock",
     "vichan",
     "vk",
