@@ -68,6 +68,22 @@ class GelbooruBase():
         yield "https://img2.gelbooru.com" + path
         yield "https://img1.gelbooru.com" + path
 
+    def _notes(self, post, page):
+        notes_data = text.extr(page, '<section id="notes"', '</section>')
+        if not notes_data:
+            return
+
+        post["notes"] = notes = []
+        extr = text.extract
+        for note in text.extract_iter(notes_data, '<article', '</article>'):
+            notes.append({
+                "width" : int(extr(note, 'data-width="', '"')[0]),
+                "height": int(extr(note, 'data-height="', '"')[0]),
+                "x"     : int(extr(note, 'data-x="', '"')[0]),
+                "y"     : int(extr(note, 'data-y="', '"')[0]),
+                "body"  : extr(note, 'data-body="', '"')[0],
+            })
+
 
 class GelbooruTagExtractor(GelbooruBase,
                            gelbooru_v02.GelbooruV02TagExtractor):
@@ -182,21 +198,21 @@ class GelbooruPostExtractor(GelbooruBase,
             "keywords": {
                 "notes": [
                     {
-                        "height": 553,
                         "body": "Look over this way when you talk~",
+                        "height": 553,
                         "width": 246,
                         "x": 35,
-                        "y": 72
+                        "y": 72,
                     },
                     {
-                        "height": 557,
                         "body": "Hey~\nAre you listening~?",
+                        "height": 557,
                         "width": 246,
                         "x": 1233,
-                        "y": 109
-                    }
-                ]
-            }
+                        "y": 109,
+                    },
+                ],
+            },
         }),
     )
 
