@@ -20,14 +20,14 @@ class LolisafeExtractor(BaseExtractor):
 
 
 BASE_PATTERN = LolisafeExtractor.update({
-    "bunkr": {
-        "root": "https://app.bunkr.is",
-        "pattern": r"(?:app\.)?bunkr\.(?:is|to)",
-    },
     "zzzz" : {
         "root": "https://zz.ht",
         "pattern": r"zz\.(?:ht|fo)",
     },
+    "xbunkr": {
+        "root": "https://xbunkr.com",
+        "pattern": r"xbunkr\.com",
+    }
 })
 
 
@@ -35,25 +35,6 @@ class LolisafeAlbumExtractor(LolisafeExtractor):
     subcategory = "album"
     pattern = BASE_PATTERN + "/a/([^/?#]+)"
     test = (
-        ("https://app.bunkr.is/a/Lktg9Keq", {
-            "pattern": r"https://cdn\.bunkr\.is/test-テスト-\"&>-QjgneIQv\.png",
-            "content": "0c8768055e4e20e7c7259608b67799171b691140",
-            "keyword": {
-                "album_id": "Lktg9Keq",
-                "album_name": 'test テスト "&>',
-                "count": 1,
-                "filename": 'test-テスト-"&>-QjgneIQv',
-                "id": "QjgneIQv",
-                "name": 'test-テスト-"&>',
-                "num": int,
-            },
-        }),
-        # mp4 (#2239)
-        ("https://bunkr.is/a/ptRHaCn2", {
-            "pattern": r"https://media-files\.bunkr\.is/_-RnHoW69L\.mp4",
-            "content": "80e61d1dbc5896ae7ef9a28734c747b28b320471",
-        }),
-        ("https://bunkr.to/a/Lktg9Keq"),
         ("https://zz.ht/a/lop7W6EZ", {
             "pattern": r"https://z\.zz\.fo/(4anuY|ih560)\.png",
             "count": 2,
@@ -63,6 +44,15 @@ class LolisafeAlbumExtractor(LolisafeExtractor):
             },
         }),
         ("https://zz.fo/a/lop7W6EZ"),
+        ("https://xbunkr.com/a/TA0bu3F4", {
+            "pattern": r"https://media\.xbunkr\.com/[^.]+\.\w+",
+            "count": 861,
+            "keyword": {
+                "album_id": "TA0bu3F4",
+                "album_name": "Hannahowo Onlyfans Photos",
+            }
+        }),
+        ("https://xbunkr.com/a/GNQc2I5d"),
     )
 
     def __init__(self, match):
@@ -71,11 +61,7 @@ class LolisafeAlbumExtractor(LolisafeExtractor):
 
         domain = self.config("domain")
         if domain is None or domain == "auto":
-            if self.category == "bunkr":
-                self.root = "https://app.bunkr.is"
-            else:
-                self.root = text.root_from_url(match.group(0))
-
+            self.root = text.root_from_url(match.group(0))
         else:
             self.root = text.ensure_http_scheme(domain)
 
@@ -89,10 +75,6 @@ class LolisafeAlbumExtractor(LolisafeExtractor):
                 data["_fallback"] = file["_fallback"]
             text.nameext_from_url(url, data)
             data["name"], sep, data["id"] = data["filename"].rpartition("-")
-
-            if data["extension"] == "mp4":
-                url = url.replace(
-                    "//cdn.bunkr.is/", "//media-files.bunkr.is/", 1)
             yield Message.Url, url, data
 
     def fetch_album(self, album_id):
